==> kdepim-addons-16.11.80.tar.xz: kdepim-addons-16.11.80/plugins/plasma/pimeventsplugin/autotests/pimeventsplugintest.h <==
/*
 * Copyright (C) 2016  Daniel Vrátil <dvratil@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#ifndef PIMEVENTSPLUGINTEST_H
#define PIMEVENTSPLUGINTEST_H

#include <QObject>
#include <QMultiHash>
#include <KCalCore/Event>

class QDate;
namespace CalendarEvents
{
class EventData;
}
class FakePimDataSource;

using DateEventDataHash = QMultiHash<QDate, CalendarEvents::EventData>;

class PimEventsPluginTest : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void initTestCase();
    void testLoadEventsForDataRange();
    void testEventAdded();
    void testEventModified();
    void testEventRemoved();

private:
    bool compareEventDataHashes(const DateEventDataHash &actual,
                                const DateEventDataHash &expected);
    DateEventDataHash populateCalendar(FakePimDataSource *source, bool uniqueEventData);
    QVector<CalendarEvents::EventData> findEventData(const KCalCore::Event::Ptr &event,
            const DateEventDataHash &allData);
};

#endif

==> kdepim-addons_18.08.3.orig.tar.xz: kdepim-addons-18.08.3/plugins/plasma/pimeventsplugin/autotests/pimeventsplugintest.h <==
/*
 * Copyright (C) 2016  Daniel Vrátil <dvratil@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#ifndef PIMEVENTSPLUGINTEST_H
#define PIMEVENTSPLUGINTEST_H

#include <QObject>
#include <QMultiHash>
#include <KCalCore/Event>

class QDate;
namespace CalendarEvents {
class EventData;
}
class FakePimDataSource;

using DateEventDataHash = QMultiHash<QDate, CalendarEvents::EventData>;

class PimEventsPluginTest : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void initTestCase();
    void testLoadEventsForDataRange();
    void testEventAdded();
    void testEventModified();
    void testEventRemoved();

private:
    bool compareEventDataHashes(const DateEventDataHash &actual, const DateEventDataHash &expected);
    DateEventDataHash populateCalendar(FakePimDataSource *source, bool uniqueEventData);
    QVector<CalendarEvents::EventData> findEventData(const KCalCore::Event::Ptr &event, const DateEventDataHash &allData);
};

#endif
